.. _quantum-hydrogen:

quantum/hydrogen.py
===================

**Description**


Hydrogen atom.

See :ref:`quantum-quantum_common`.


.. image:: /../doc/images/gallery/quantum-hydrogen.png


:download:`source code </../sfepy/examples/quantum/hydrogen.py>`

.. literalinclude:: /../sfepy/examples/quantum/hydrogen.py

